import click
import subprocess as sb 


def run(command):
    sb.run(command, shell=True)

apps='''gimp
da-vinci-resolve
wine
libreoffice-full
krita
brave-browser
brave-beta
brave-nightly
edge-beta
firefox
chrome
lutris
g-drive
blender
python3
miniconda
anaconda
pip3
java-development-kit-11
java-development-kit-14-oracle
vscode
atom-editor
thonny
sublimetext
g++
clang
gcc 
pycharm-community
intellij-community
thunderbird
evolution
kazam
golang
r-lang
rstudio
virtualbox
scribus
plank-dock
calibre
chromium
zoom
dropbox
vlc
skype
gparted
minecraft
audacity
audacious
htop
dos-box
desmume
vim
kate
gedit
jedit
kate
emacs
telegram
signal
g-earth
steam
codeblocks
netbeans
lazarus-pascal
geany
dconf
spyder
terminator
kdenlive
obs
simple-screen-recorder
geogebra
etcher
cheese
spotify
discord
tuxpaint
stellarium
pinta
mypaint
shotwell
nodejs'''
	

@click.group()
@click.version_option('0.1.4', prog_name= 'Lola')
def main():
	'''I am Lola! Your assistant who can help you setup your Linux in an easy way! You can know more about me in https://github.com/arghyagod-coder/lola.

I can help you install apps through terminal, and you need to know almost nothing about the terminal to do so! Just simple prompts will be enough'''
	pass

@main.command('check-apps')
def checkapps():
	print(apps)

@main.command('install', help= ('Install an app'))
@click.argument('filesl', nargs=-1)
def install(filesl): 
	for files in filesl:
		run(f'cd ~/Downloads; wget https://raw.githubusercontent.com/arghyagod-coder/lola/master/lola/scripts/{files}.sh; bash {files}.sh; rm {files}.sh')



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['lolacli']

package_data = \
{'': ['*'], 'lolacli': ['scripts/*']}

install_requires = \
['click>=8.0.1,<9.0.0']

entry_points = \
{'console_scripts': ['lola = lolacli.lolacli:main']}

setup_kwargs = {
    'name': 'lolacli',
    'version': '0.1.7',
    'description': 'A simple cli tool to help beginners install apps in Linux',
    'long_description': '## LOLA\n`lola` : A simple CLI for installing packages on Linux easily \n\n[![GitHub license](https://github.com/arghyagod-coder/lola/blob/master/LICENSE)\n\n\n#### Dependencies\n+ click\n\n',
    'author': 'Arghya Sarkar',
    'author_email': 'arghyasarkar.joker@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/arghyagod-coder/lola',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
